import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, NgModule, Injectable } from '@angular/core';
import * as i1 from '@angular/platform-browser';
import { Deferred } from 'novo-elements/utils';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3 from 'novo-elements/elements/button';
import { NovoButtonModule } from 'novo-elements/elements/button';
import * as i1$1 from 'novo-elements/services';

// NG2
class NovoToastElement {
    set message(m) {
        this._message = this.sanitizer.bypassSecurityTrustHtml(m);
    }
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.appearance = 'banner';
        this.theme = 'danger';
        this.icon = 'caution';
        this.hasDialogue = false;
        this.isCloseable = false;
        this.closed = new EventEmitter();
        this.show = false;
        this.animate = false;
        this.parent = null;
        this.launched = false;
        this.onActionPromise = Deferred();
    }
    ngOnInit() {
        if (!this.launched) {
            // clear position and time
            this.position = null;
            this.time = null;
            // set icon and styling
            this.iconClass = `bhi-${this.icon}`;
            this.alertTheme = `${this.theme} toast-container embedded`;
            if (this.hasDialogue) {
                this.alertTheme += ' dialogue';
            }
        }
    }
    ngOnChanges(changes) {
        // set icon and styling
        this.iconClass = `bhi-${this.icon}`;
        this.alertTheme = `${this.theme} toast-container embedded`;
        if (this.hasDialogue) {
            this.alertTheme += ' dialogue';
        }
    }
    clickHandler(event) {
        if (!this.isCloseable) {
            if (event) {
                event.stopPropagation();
                event.preventDefault();
            }
            if (this.parent) {
                this.parent.hide(this);
            }
            else {
                this.closed.emit({ closed: true });
            }
        }
    }
    close(event) {
        if (event) {
            event.stopPropagation();
            event.preventDefault();
        }
        if (this.parent) {
            this.parent.hide(this);
        }
        else {
            this.closed.emit({ closed: true });
        }
    }
    actionHandler(event) {
        this.onActionPromise.resolve(event);
    }
    onAction(fn) {
        return this.onActionPromise.then(fn);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastElement, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.12", type: NovoToastElement, selector: "novo-toast", inputs: { appearance: "appearance", theme: "theme", icon: "icon", title: "title", action: "action", hasDialogue: "hasDialogue", link: "link", isCloseable: "isCloseable", message: "message" }, outputs: { closed: "closed" }, host: { listeners: { "click": "!isCloseable && clickHandler($event)" }, properties: { "class": "alertTheme", "class.growl": "appearance == \"growl\"", "class.banner": "appearance == \"banner\"", "class.show": "show", "class.animate": "animate", "class.embedded": "embedded", "attr.theme": "theme" } }, usesOnChanges: true, ngImport: i0, template: `
    <div class="toast-icon">
      <i [ngClass]="iconClass"></i>
    </div>
    <div class="toast-content">
      <h5 *ngIf="title">{{ title }}</h5>
      <p *ngIf="_message" [class.message-only]="!title" [innerHtml]="_message"></p>
      <div *ngIf="link" class="link-generated">
        <input type="text" [value]="link" onfocus="this.select();" />
      </div>
      <div class="dialogue">
        <ng-content></ng-content>
      </div>
      <div *ngIf="action" class="action">
        <button theme="dialogue" color="white" (click)="actionHandler($event)">{{ action }}</button>
      </div>
    </div>
    <div class="close-icon" *ngIf="isCloseable" (click)="close($event)">
      <i class="bhi-times"></i>
    </div>
  `, isInline: true, styles: [":host{display:grid;grid-template-columns:5rem 1fr 15px;justify-content:flex-start;align-content:center;align-items:center;position:relative;background:#0d2d42;color:#fff;padding:1rem;box-shadow:0 1px 3px #00000026}:host.show{display:grid!important}:host.launched{display:none;position:fixed;z-index:9999}:host .toast-icon{display:flex;justify-content:center;align-content:center;align-items:center;width:32px;height:32px;background:#00000026;border-radius:3px}:host .close-icon{display:flex;justify-content:center;align-content:center;align-items:center;align-self:flex-start;cursor:pointer;height:100%}:host .toast-icon i,:host .close-icon i{display:flex;position:relative;font-size:1.2rem;line-height:1.2}:host.toast-container .toast-content .link-generated{width:100%;position:relative}:host.toast-container .toast-content .link-generated input{background:transparent!important;border:none;border-bottom:1px solid #afb9c0;border-radius:0;outline:none;height:2rem;width:95%;margin:0;padding:0;box-shadow:none;box-sizing:content-box;transition:all .3s;color:#fff;text-overflow:ellipsis}:host.toast-container .toast-content .link-generated input:focus{background-color:#4a89dc}:host.toast-container .toast-content .link-generated input:hover{border-bottom:1px solid #5f6d78}:host p{white-space:pre-line}:host h5{display:block;font-size:1.4rem;color:inherit}:host .toast-content>p{margin:0;max-width:inherit;font-size:1.3rem}:host .toast-content>p.message-only{padding:0;font-size:1.4rem}:host.text{background:#3d464d}:host.neutral{background:#4f5361}:host.background{background:#f7f7f7}:host.background .toast-content>h5{color:#3d464d!important}:host.background i,:host.background p{color:#3d464d}:host.fixedBottom,:host.fixedTop{left:0;right:0}:host.fixedBottom{bottom:-100%;padding-bottom:20px;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.fixedBottom.animate{padding-bottom:10px;bottom:0}:host.fixedBottom:nth-last-of-type(2){bottom:25px;z-index:9997;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(3){bottom:50px;z-index:9996;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(4){bottom:75px;z-index:9995;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(5){bottom:100px;z-index:9994;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(6){bottom:125px;z-index:9993;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(7){bottom:150px;z-index:9992;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(8){bottom:175px;z-index:9991;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(9){bottom:200px;z-index:9990;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(10){bottom:225px;z-index:9989;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(11){bottom:250px;z-index:9988;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(12){bottom:275px;z-index:9987;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(13){bottom:300px;z-index:9986;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(14){bottom:325px;z-index:9985;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(15){bottom:350px;z-index:9984;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(16){bottom:375px;z-index:9983;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(17){bottom:400px;z-index:9982;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(18){bottom:425px;z-index:9981;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(19){bottom:450px;z-index:9980;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(20){bottom:475px;z-index:9979;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(21){bottom:500px;z-index:9978;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(22){bottom:525px;z-index:9977;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(23){bottom:550px;z-index:9976;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(24){bottom:575px;z-index:9975;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(25){bottom:600px;z-index:9974;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(26){bottom:625px;z-index:9973;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(27){bottom:650px;z-index:9972;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(28){bottom:675px;z-index:9971;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(29){bottom:700px;z-index:9970;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(30){bottom:725px;z-index:9969;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(31){bottom:750px;z-index:9968;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(32){bottom:775px;z-index:9967;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(33){bottom:800px;z-index:9966;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(34){bottom:825px;z-index:9965;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(35){bottom:850px;z-index:9964;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(36){bottom:875px;z-index:9963;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(37){bottom:900px;z-index:9962;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(38){bottom:925px;z-index:9961;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(39){bottom:950px;z-index:9960;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(40){bottom:975px;z-index:9959;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(41){bottom:1000px;z-index:9958;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(42){bottom:1025px;z-index:9957;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(43){bottom:1050px;z-index:9956;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(44){bottom:1075px;z-index:9955;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(45){bottom:1100px;z-index:9954;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(46){bottom:1125px;z-index:9953;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(47){bottom:1150px;z-index:9952;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(48){bottom:1175px;z-index:9951;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(49){bottom:1200px;z-index:9950;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(50){bottom:1225px;z-index:9949;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(51){bottom:1250px;z-index:9948;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(52){bottom:1275px;z-index:9947;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(53){bottom:1300px;z-index:9946;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(54){bottom:1325px;z-index:9945;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(55){bottom:1350px;z-index:9944;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(56){bottom:1375px;z-index:9943;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(57){bottom:1400px;z-index:9942;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(58){bottom:1425px;z-index:9941;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(59){bottom:1450px;z-index:9940;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(60){bottom:1475px;z-index:9939;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(61){bottom:1500px;z-index:9938;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(62){bottom:1525px;z-index:9937;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(63){bottom:1550px;z-index:9936;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(64){bottom:1575px;z-index:9935;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(65){bottom:1600px;z-index:9934;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(66){bottom:1625px;z-index:9933;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(67){bottom:1650px;z-index:9932;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(68){bottom:1675px;z-index:9931;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(69){bottom:1700px;z-index:9930;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(70){bottom:1725px;z-index:9929;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(71){bottom:1750px;z-index:9928;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(72){bottom:1775px;z-index:9927;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(73){bottom:1800px;z-index:9926;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(74){bottom:1825px;z-index:9925;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(75){bottom:1850px;z-index:9924;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(76){bottom:1875px;z-index:9923;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(77){bottom:1900px;z-index:9922;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(78){bottom:1925px;z-index:9921;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(79){bottom:1950px;z-index:9920;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(80){bottom:1975px;z-index:9919;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(81){bottom:2000px;z-index:9918;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(82){bottom:2025px;z-index:9917;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(83){bottom:2050px;z-index:9916;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(84){bottom:2075px;z-index:9915;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(85){bottom:2100px;z-index:9914;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(86){bottom:2125px;z-index:9913;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(87){bottom:2150px;z-index:9912;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(88){bottom:2175px;z-index:9911;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(89){bottom:2200px;z-index:9910;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(90){bottom:2225px;z-index:9909;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(91){bottom:2250px;z-index:9908;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(92){bottom:2275px;z-index:9907;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(93){bottom:2300px;z-index:9906;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(94){bottom:2325px;z-index:9905;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(95){bottom:2350px;z-index:9904;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(96){bottom:2375px;z-index:9903;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(97){bottom:2400px;z-index:9902;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(98){bottom:2425px;z-index:9901;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(99){bottom:2450px;z-index:9900;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(100){bottom:2475px;z-index:9899;filter:brightness(.8571428571)}:host.fixedTop{top:-100%;padding-top:20px;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.fixedTop.animate{padding-top:10px;top:0}:host.fixedTop:nth-last-of-type(2){top:25px;z-index:9997;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(3){top:50px;z-index:9996;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(4){top:75px;z-index:9995;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(5){top:100px;z-index:9994;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(6){top:125px;z-index:9993;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(7){top:150px;z-index:9992;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(8){top:175px;z-index:9991;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(9){top:200px;z-index:9990;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(10){top:225px;z-index:9989;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(11){top:250px;z-index:9988;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(12){top:275px;z-index:9987;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(13){top:300px;z-index:9986;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(14){top:325px;z-index:9985;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(15){top:350px;z-index:9984;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(16){top:375px;z-index:9983;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(17){top:400px;z-index:9982;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(18){top:425px;z-index:9981;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(19){top:450px;z-index:9980;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(20){top:475px;z-index:9979;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(21){top:500px;z-index:9978;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(22){top:525px;z-index:9977;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(23){top:550px;z-index:9976;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(24){top:575px;z-index:9975;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(25){top:600px;z-index:9974;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(26){top:625px;z-index:9973;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(27){top:650px;z-index:9972;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(28){top:675px;z-index:9971;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(29){top:700px;z-index:9970;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(30){top:725px;z-index:9969;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(31){top:750px;z-index:9968;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(32){top:775px;z-index:9967;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(33){top:800px;z-index:9966;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(34){top:825px;z-index:9965;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(35){top:850px;z-index:9964;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(36){top:875px;z-index:9963;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(37){top:900px;z-index:9962;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(38){top:925px;z-index:9961;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(39){top:950px;z-index:9960;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(40){top:975px;z-index:9959;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(41){top:1000px;z-index:9958;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(42){top:1025px;z-index:9957;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(43){top:1050px;z-index:9956;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(44){top:1075px;z-index:9955;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(45){top:1100px;z-index:9954;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(46){top:1125px;z-index:9953;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(47){top:1150px;z-index:9952;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(48){top:1175px;z-index:9951;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(49){top:1200px;z-index:9950;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(50){top:1225px;z-index:9949;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(51){top:1250px;z-index:9948;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(52){top:1275px;z-index:9947;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(53){top:1300px;z-index:9946;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(54){top:1325px;z-index:9945;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(55){top:1350px;z-index:9944;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(56){top:1375px;z-index:9943;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(57){top:1400px;z-index:9942;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(58){top:1425px;z-index:9941;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(59){top:1450px;z-index:9940;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(60){top:1475px;z-index:9939;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(61){top:1500px;z-index:9938;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(62){top:1525px;z-index:9937;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(63){top:1550px;z-index:9936;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(64){top:1575px;z-index:9935;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(65){top:1600px;z-index:9934;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(66){top:1625px;z-index:9933;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(67){top:1650px;z-index:9932;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(68){top:1675px;z-index:9931;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(69){top:1700px;z-index:9930;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(70){top:1725px;z-index:9929;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(71){top:1750px;z-index:9928;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(72){top:1775px;z-index:9927;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(73){top:1800px;z-index:9926;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(74){top:1825px;z-index:9925;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(75){top:1850px;z-index:9924;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(76){top:1875px;z-index:9923;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(77){top:1900px;z-index:9922;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(78){top:1925px;z-index:9921;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(79){top:1950px;z-index:9920;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(80){top:1975px;z-index:9919;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(81){top:2000px;z-index:9918;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(82){top:2025px;z-index:9917;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(83){top:2050px;z-index:9916;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(84){top:2075px;z-index:9915;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(85){top:2100px;z-index:9914;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(86){top:2125px;z-index:9913;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(87){top:2150px;z-index:9912;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(88){top:2175px;z-index:9911;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(89){top:2200px;z-index:9910;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(90){top:2225px;z-index:9909;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(91){top:2250px;z-index:9908;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(92){top:2275px;z-index:9907;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(93){top:2300px;z-index:9906;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(94){top:2325px;z-index:9905;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(95){top:2350px;z-index:9904;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(96){top:2375px;z-index:9903;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(97){top:2400px;z-index:9902;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(98){top:2425px;z-index:9901;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(99){top:2450px;z-index:9900;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(100){top:2475px;z-index:9899;filter:brightness(.8571428571)}:host.embedded.fixedBottom,:host.embedded.fixedTop{top:auto;left:auto;right:auto;width:inherit;margin:-1rem -3rem}:host.embedded.fixedBottom.animate,:host.embedded.fixedTop.animate{top:auto}:host[class*=growl]{border-radius:3px;max-width:350px}:host.growlBottomLeft,:host.growlTopLeft{left:-100%;right:auto;width:calc(100% - 30px);transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomLeft.animate,:host.growlTopLeft.animate{left:15px}:host.growlTopLeft,:host.growlTopRight{top:1rem}:host.growlTopLeft:nth-last-of-type(2),:host.growlTopRight:nth-last-of-type(2){top:50px;transform:scale(.96);z-index:9997;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(3),:host.growlTopRight:nth-last-of-type(3){top:75px;transform:scale(.96);z-index:9996;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(4),:host.growlTopRight:nth-last-of-type(4){top:100px;transform:scale(.96);z-index:9995;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(5),:host.growlTopRight:nth-last-of-type(5){top:125px;transform:scale(.96);z-index:9994;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(6),:host.growlTopRight:nth-last-of-type(6){top:150px;transform:scale(.96);z-index:9993;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(7),:host.growlTopRight:nth-last-of-type(7){top:175px;transform:scale(.96);z-index:9992;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(8),:host.growlTopRight:nth-last-of-type(8){top:200px;transform:scale(.96);z-index:9991;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(9),:host.growlTopRight:nth-last-of-type(9){top:225px;transform:scale(.96);z-index:9990;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(10),:host.growlTopRight:nth-last-of-type(10){top:250px;transform:scale(.96);z-index:9989;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(11),:host.growlTopRight:nth-last-of-type(11){top:275px;transform:scale(.96);z-index:9988;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(12),:host.growlTopRight:nth-last-of-type(12){top:300px;transform:scale(.96);z-index:9987;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(13),:host.growlTopRight:nth-last-of-type(13){top:325px;transform:scale(.96);z-index:9986;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(14),:host.growlTopRight:nth-last-of-type(14){top:350px;transform:scale(.96);z-index:9985;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(15),:host.growlTopRight:nth-last-of-type(15){top:375px;transform:scale(.96);z-index:9984;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(16),:host.growlTopRight:nth-last-of-type(16){top:400px;transform:scale(.96);z-index:9983;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(17),:host.growlTopRight:nth-last-of-type(17){top:425px;transform:scale(.96);z-index:9982;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(18),:host.growlTopRight:nth-last-of-type(18){top:450px;transform:scale(.96);z-index:9981;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(19),:host.growlTopRight:nth-last-of-type(19){top:475px;transform:scale(.96);z-index:9980;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(20),:host.growlTopRight:nth-last-of-type(20){top:500px;transform:scale(.96);z-index:9979;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(21),:host.growlTopRight:nth-last-of-type(21){top:525px;transform:scale(.96);z-index:9978;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(22),:host.growlTopRight:nth-last-of-type(22){top:550px;transform:scale(.96);z-index:9977;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(23),:host.growlTopRight:nth-last-of-type(23){top:575px;transform:scale(.96);z-index:9976;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(24),:host.growlTopRight:nth-last-of-type(24){top:600px;transform:scale(.96);z-index:9975;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(25),:host.growlTopRight:nth-last-of-type(25){top:625px;transform:scale(.96);z-index:9974;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(26),:host.growlTopRight:nth-last-of-type(26){top:650px;transform:scale(.96);z-index:9973;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(27),:host.growlTopRight:nth-last-of-type(27){top:675px;transform:scale(.96);z-index:9972;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(28),:host.growlTopRight:nth-last-of-type(28){top:700px;transform:scale(.96);z-index:9971;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(29),:host.growlTopRight:nth-last-of-type(29){top:725px;transform:scale(.96);z-index:9970;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(30),:host.growlTopRight:nth-last-of-type(30){top:750px;transform:scale(.96);z-index:9969;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(31),:host.growlTopRight:nth-last-of-type(31){top:775px;transform:scale(.96);z-index:9968;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(32),:host.growlTopRight:nth-last-of-type(32){top:800px;transform:scale(.96);z-index:9967;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(33),:host.growlTopRight:nth-last-of-type(33){top:825px;transform:scale(.96);z-index:9966;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(34),:host.growlTopRight:nth-last-of-type(34){top:850px;transform:scale(.96);z-index:9965;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(35),:host.growlTopRight:nth-last-of-type(35){top:875px;transform:scale(.96);z-index:9964;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(36),:host.growlTopRight:nth-last-of-type(36){top:900px;transform:scale(.96);z-index:9963;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(37),:host.growlTopRight:nth-last-of-type(37){top:925px;transform:scale(.96);z-index:9962;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(38),:host.growlTopRight:nth-last-of-type(38){top:950px;transform:scale(.96);z-index:9961;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(39),:host.growlTopRight:nth-last-of-type(39){top:975px;transform:scale(.96);z-index:9960;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(40),:host.growlTopRight:nth-last-of-type(40){top:1000px;transform:scale(.96);z-index:9959;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(41),:host.growlTopRight:nth-last-of-type(41){top:1025px;transform:scale(.96);z-index:9958;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(42),:host.growlTopRight:nth-last-of-type(42){top:1050px;transform:scale(.96);z-index:9957;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(43),:host.growlTopRight:nth-last-of-type(43){top:1075px;transform:scale(.96);z-index:9956;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(44),:host.growlTopRight:nth-last-of-type(44){top:1100px;transform:scale(.96);z-index:9955;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(45),:host.growlTopRight:nth-last-of-type(45){top:1125px;transform:scale(.96);z-index:9954;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(46),:host.growlTopRight:nth-last-of-type(46){top:1150px;transform:scale(.96);z-index:9953;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(47),:host.growlTopRight:nth-last-of-type(47){top:1175px;transform:scale(.96);z-index:9952;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(48),:host.growlTopRight:nth-last-of-type(48){top:1200px;transform:scale(.96);z-index:9951;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(49),:host.growlTopRight:nth-last-of-type(49){top:1225px;transform:scale(.96);z-index:9950;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(50),:host.growlTopRight:nth-last-of-type(50){top:1250px;transform:scale(.96);z-index:9949;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(51),:host.growlTopRight:nth-last-of-type(51){top:1275px;transform:scale(.96);z-index:9948;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(52),:host.growlTopRight:nth-last-of-type(52){top:1300px;transform:scale(.96);z-index:9947;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(53),:host.growlTopRight:nth-last-of-type(53){top:1325px;transform:scale(.96);z-index:9946;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(54),:host.growlTopRight:nth-last-of-type(54){top:1350px;transform:scale(.96);z-index:9945;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(55),:host.growlTopRight:nth-last-of-type(55){top:1375px;transform:scale(.96);z-index:9944;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(56),:host.growlTopRight:nth-last-of-type(56){top:1400px;transform:scale(.96);z-index:9943;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(57),:host.growlTopRight:nth-last-of-type(57){top:1425px;transform:scale(.96);z-index:9942;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(58),:host.growlTopRight:nth-last-of-type(58){top:1450px;transform:scale(.96);z-index:9941;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(59),:host.growlTopRight:nth-last-of-type(59){top:1475px;transform:scale(.96);z-index:9940;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(60),:host.growlTopRight:nth-last-of-type(60){top:1500px;transform:scale(.96);z-index:9939;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(61),:host.growlTopRight:nth-last-of-type(61){top:1525px;transform:scale(.96);z-index:9938;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(62),:host.growlTopRight:nth-last-of-type(62){top:1550px;transform:scale(.96);z-index:9937;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(63),:host.growlTopRight:nth-last-of-type(63){top:1575px;transform:scale(.96);z-index:9936;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(64),:host.growlTopRight:nth-last-of-type(64){top:1600px;transform:scale(.96);z-index:9935;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(65),:host.growlTopRight:nth-last-of-type(65){top:1625px;transform:scale(.96);z-index:9934;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(66),:host.growlTopRight:nth-last-of-type(66){top:1650px;transform:scale(.96);z-index:9933;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(67),:host.growlTopRight:nth-last-of-type(67){top:1675px;transform:scale(.96);z-index:9932;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(68),:host.growlTopRight:nth-last-of-type(68){top:1700px;transform:scale(.96);z-index:9931;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(69),:host.growlTopRight:nth-last-of-type(69){top:1725px;transform:scale(.96);z-index:9930;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(70),:host.growlTopRight:nth-last-of-type(70){top:1750px;transform:scale(.96);z-index:9929;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(71),:host.growlTopRight:nth-last-of-type(71){top:1775px;transform:scale(.96);z-index:9928;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(72),:host.growlTopRight:nth-last-of-type(72){top:1800px;transform:scale(.96);z-index:9927;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(73),:host.growlTopRight:nth-last-of-type(73){top:1825px;transform:scale(.96);z-index:9926;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(74),:host.growlTopRight:nth-last-of-type(74){top:1850px;transform:scale(.96);z-index:9925;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(75),:host.growlTopRight:nth-last-of-type(75){top:1875px;transform:scale(.96);z-index:9924;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(76),:host.growlTopRight:nth-last-of-type(76){top:1900px;transform:scale(.96);z-index:9923;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(77),:host.growlTopRight:nth-last-of-type(77){top:1925px;transform:scale(.96);z-index:9922;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(78),:host.growlTopRight:nth-last-of-type(78){top:1950px;transform:scale(.96);z-index:9921;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(79),:host.growlTopRight:nth-last-of-type(79){top:1975px;transform:scale(.96);z-index:9920;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(80),:host.growlTopRight:nth-last-of-type(80){top:2000px;transform:scale(.96);z-index:9919;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(81),:host.growlTopRight:nth-last-of-type(81){top:2025px;transform:scale(.96);z-index:9918;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(82),:host.growlTopRight:nth-last-of-type(82){top:2050px;transform:scale(.96);z-index:9917;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(83),:host.growlTopRight:nth-last-of-type(83){top:2075px;transform:scale(.96);z-index:9916;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(84),:host.growlTopRight:nth-last-of-type(84){top:2100px;transform:scale(.96);z-index:9915;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(85),:host.growlTopRight:nth-last-of-type(85){top:2125px;transform:scale(.96);z-index:9914;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(86),:host.growlTopRight:nth-last-of-type(86){top:2150px;transform:scale(.96);z-index:9913;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(87),:host.growlTopRight:nth-last-of-type(87){top:2175px;transform:scale(.96);z-index:9912;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(88),:host.growlTopRight:nth-last-of-type(88){top:2200px;transform:scale(.96);z-index:9911;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(89),:host.growlTopRight:nth-last-of-type(89){top:2225px;transform:scale(.96);z-index:9910;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(90),:host.growlTopRight:nth-last-of-type(90){top:2250px;transform:scale(.96);z-index:9909;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(91),:host.growlTopRight:nth-last-of-type(91){top:2275px;transform:scale(.96);z-index:9908;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(92),:host.growlTopRight:nth-last-of-type(92){top:2300px;transform:scale(.96);z-index:9907;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(93),:host.growlTopRight:nth-last-of-type(93){top:2325px;transform:scale(.96);z-index:9906;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(94),:host.growlTopRight:nth-last-of-type(94){top:2350px;transform:scale(.96);z-index:9905;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(95),:host.growlTopRight:nth-last-of-type(95){top:2375px;transform:scale(.96);z-index:9904;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(96),:host.growlTopRight:nth-last-of-type(96){top:2400px;transform:scale(.96);z-index:9903;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(97),:host.growlTopRight:nth-last-of-type(97){top:2425px;transform:scale(.96);z-index:9902;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(98),:host.growlTopRight:nth-last-of-type(98){top:2450px;transform:scale(.96);z-index:9901;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(99),:host.growlTopRight:nth-last-of-type(99){top:2475px;transform:scale(.96);z-index:9900;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(100),:host.growlTopRight:nth-last-of-type(100){top:2500px;transform:scale(.96);z-index:9899;filter:brightness(.8571428571)}:host.growlBottomLeft,:host.growlBottomRight{bottom:1rem}:host.growlBottomLeft:nth-last-of-type(2),:host.growlBottomRight:nth-last-of-type(2){bottom:50px;transform:scale(.96);z-index:9997;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(3),:host.growlBottomRight:nth-last-of-type(3){bottom:75px;transform:scale(.96);z-index:9996;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(4),:host.growlBottomRight:nth-last-of-type(4){bottom:100px;transform:scale(.96);z-index:9995;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(5),:host.growlBottomRight:nth-last-of-type(5){bottom:125px;transform:scale(.96);z-index:9994;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(6),:host.growlBottomRight:nth-last-of-type(6){bottom:150px;transform:scale(.96);z-index:9993;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(7),:host.growlBottomRight:nth-last-of-type(7){bottom:175px;transform:scale(.96);z-index:9992;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(8),:host.growlBottomRight:nth-last-of-type(8){bottom:200px;transform:scale(.96);z-index:9991;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(9),:host.growlBottomRight:nth-last-of-type(9){bottom:225px;transform:scale(.96);z-index:9990;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(10),:host.growlBottomRight:nth-last-of-type(10){bottom:250px;transform:scale(.96);z-index:9989;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(11),:host.growlBottomRight:nth-last-of-type(11){bottom:275px;transform:scale(.96);z-index:9988;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(12),:host.growlBottomRight:nth-last-of-type(12){bottom:300px;transform:scale(.96);z-index:9987;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(13),:host.growlBottomRight:nth-last-of-type(13){bottom:325px;transform:scale(.96);z-index:9986;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(14),:host.growlBottomRight:nth-last-of-type(14){bottom:350px;transform:scale(.96);z-index:9985;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(15),:host.growlBottomRight:nth-last-of-type(15){bottom:375px;transform:scale(.96);z-index:9984;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(16),:host.growlBottomRight:nth-last-of-type(16){bottom:400px;transform:scale(.96);z-index:9983;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(17),:host.growlBottomRight:nth-last-of-type(17){bottom:425px;transform:scale(.96);z-index:9982;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(18),:host.growlBottomRight:nth-last-of-type(18){bottom:450px;transform:scale(.96);z-index:9981;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(19),:host.growlBottomRight:nth-last-of-type(19){bottom:475px;transform:scale(.96);z-index:9980;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(20),:host.growlBottomRight:nth-last-of-type(20){bottom:500px;transform:scale(.96);z-index:9979;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(21),:host.growlBottomRight:nth-last-of-type(21){bottom:525px;transform:scale(.96);z-index:9978;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(22),:host.growlBottomRight:nth-last-of-type(22){bottom:550px;transform:scale(.96);z-index:9977;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(23),:host.growlBottomRight:nth-last-of-type(23){bottom:575px;transform:scale(.96);z-index:9976;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(24),:host.growlBottomRight:nth-last-of-type(24){bottom:600px;transform:scale(.96);z-index:9975;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(25),:host.growlBottomRight:nth-last-of-type(25){bottom:625px;transform:scale(.96);z-index:9974;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(26),:host.growlBottomRight:nth-last-of-type(26){bottom:650px;transform:scale(.96);z-index:9973;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(27),:host.growlBottomRight:nth-last-of-type(27){bottom:675px;transform:scale(.96);z-index:9972;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(28),:host.growlBottomRight:nth-last-of-type(28){bottom:700px;transform:scale(.96);z-index:9971;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(29),:host.growlBottomRight:nth-last-of-type(29){bottom:725px;transform:scale(.96);z-index:9970;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(30),:host.growlBottomRight:nth-last-of-type(30){bottom:750px;transform:scale(.96);z-index:9969;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(31),:host.growlBottomRight:nth-last-of-type(31){bottom:775px;transform:scale(.96);z-index:9968;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(32),:host.growlBottomRight:nth-last-of-type(32){bottom:800px;transform:scale(.96);z-index:9967;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(33),:host.growlBottomRight:nth-last-of-type(33){bottom:825px;transform:scale(.96);z-index:9966;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(34),:host.growlBottomRight:nth-last-of-type(34){bottom:850px;transform:scale(.96);z-index:9965;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(35),:host.growlBottomRight:nth-last-of-type(35){bottom:875px;transform:scale(.96);z-index:9964;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(36),:host.growlBottomRight:nth-last-of-type(36){bottom:900px;transform:scale(.96);z-index:9963;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(37),:host.growlBottomRight:nth-last-of-type(37){bottom:925px;transform:scale(.96);z-index:9962;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(38),:host.growlBottomRight:nth-last-of-type(38){bottom:950px;transform:scale(.96);z-index:9961;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(39),:host.growlBottomRight:nth-last-of-type(39){bottom:975px;transform:scale(.96);z-index:9960;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(40),:host.growlBottomRight:nth-last-of-type(40){bottom:1000px;transform:scale(.96);z-index:9959;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(41),:host.growlBottomRight:nth-last-of-type(41){bottom:1025px;transform:scale(.96);z-index:9958;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(42),:host.growlBottomRight:nth-last-of-type(42){bottom:1050px;transform:scale(.96);z-index:9957;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(43),:host.growlBottomRight:nth-last-of-type(43){bottom:1075px;transform:scale(.96);z-index:9956;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(44),:host.growlBottomRight:nth-last-of-type(44){bottom:1100px;transform:scale(.96);z-index:9955;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(45),:host.growlBottomRight:nth-last-of-type(45){bottom:1125px;transform:scale(.96);z-index:9954;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(46),:host.growlBottomRight:nth-last-of-type(46){bottom:1150px;transform:scale(.96);z-index:9953;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(47),:host.growlBottomRight:nth-last-of-type(47){bottom:1175px;transform:scale(.96);z-index:9952;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(48),:host.growlBottomRight:nth-last-of-type(48){bottom:1200px;transform:scale(.96);z-index:9951;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(49),:host.growlBottomRight:nth-last-of-type(49){bottom:1225px;transform:scale(.96);z-index:9950;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(50),:host.growlBottomRight:nth-last-of-type(50){bottom:1250px;transform:scale(.96);z-index:9949;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(51),:host.growlBottomRight:nth-last-of-type(51){bottom:1275px;transform:scale(.96);z-index:9948;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(52),:host.growlBottomRight:nth-last-of-type(52){bottom:1300px;transform:scale(.96);z-index:9947;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(53),:host.growlBottomRight:nth-last-of-type(53){bottom:1325px;transform:scale(.96);z-index:9946;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(54),:host.growlBottomRight:nth-last-of-type(54){bottom:1350px;transform:scale(.96);z-index:9945;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(55),:host.growlBottomRight:nth-last-of-type(55){bottom:1375px;transform:scale(.96);z-index:9944;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(56),:host.growlBottomRight:nth-last-of-type(56){bottom:1400px;transform:scale(.96);z-index:9943;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(57),:host.growlBottomRight:nth-last-of-type(57){bottom:1425px;transform:scale(.96);z-index:9942;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(58),:host.growlBottomRight:nth-last-of-type(58){bottom:1450px;transform:scale(.96);z-index:9941;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(59),:host.growlBottomRight:nth-last-of-type(59){bottom:1475px;transform:scale(.96);z-index:9940;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(60),:host.growlBottomRight:nth-last-of-type(60){bottom:1500px;transform:scale(.96);z-index:9939;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(61),:host.growlBottomRight:nth-last-of-type(61){bottom:1525px;transform:scale(.96);z-index:9938;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(62),:host.growlBottomRight:nth-last-of-type(62){bottom:1550px;transform:scale(.96);z-index:9937;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(63),:host.growlBottomRight:nth-last-of-type(63){bottom:1575px;transform:scale(.96);z-index:9936;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(64),:host.growlBottomRight:nth-last-of-type(64){bottom:1600px;transform:scale(.96);z-index:9935;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(65),:host.growlBottomRight:nth-last-of-type(65){bottom:1625px;transform:scale(.96);z-index:9934;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(66),:host.growlBottomRight:nth-last-of-type(66){bottom:1650px;transform:scale(.96);z-index:9933;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(67),:host.growlBottomRight:nth-last-of-type(67){bottom:1675px;transform:scale(.96);z-index:9932;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(68),:host.growlBottomRight:nth-last-of-type(68){bottom:1700px;transform:scale(.96);z-index:9931;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(69),:host.growlBottomRight:nth-last-of-type(69){bottom:1725px;transform:scale(.96);z-index:9930;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(70),:host.growlBottomRight:nth-last-of-type(70){bottom:1750px;transform:scale(.96);z-index:9929;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(71),:host.growlBottomRight:nth-last-of-type(71){bottom:1775px;transform:scale(.96);z-index:9928;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(72),:host.growlBottomRight:nth-last-of-type(72){bottom:1800px;transform:scale(.96);z-index:9927;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(73),:host.growlBottomRight:nth-last-of-type(73){bottom:1825px;transform:scale(.96);z-index:9926;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(74),:host.growlBottomRight:nth-last-of-type(74){bottom:1850px;transform:scale(.96);z-index:9925;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(75),:host.growlBottomRight:nth-last-of-type(75){bottom:1875px;transform:scale(.96);z-index:9924;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(76),:host.growlBottomRight:nth-last-of-type(76){bottom:1900px;transform:scale(.96);z-index:9923;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(77),:host.growlBottomRight:nth-last-of-type(77){bottom:1925px;transform:scale(.96);z-index:9922;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(78),:host.growlBottomRight:nth-last-of-type(78){bottom:1950px;transform:scale(.96);z-index:9921;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(79),:host.growlBottomRight:nth-last-of-type(79){bottom:1975px;transform:scale(.96);z-index:9920;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(80),:host.growlBottomRight:nth-last-of-type(80){bottom:2000px;transform:scale(.96);z-index:9919;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(81),:host.growlBottomRight:nth-last-of-type(81){bottom:2025px;transform:scale(.96);z-index:9918;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(82),:host.growlBottomRight:nth-last-of-type(82){bottom:2050px;transform:scale(.96);z-index:9917;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(83),:host.growlBottomRight:nth-last-of-type(83){bottom:2075px;transform:scale(.96);z-index:9916;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(84),:host.growlBottomRight:nth-last-of-type(84){bottom:2100px;transform:scale(.96);z-index:9915;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(85),:host.growlBottomRight:nth-last-of-type(85){bottom:2125px;transform:scale(.96);z-index:9914;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(86),:host.growlBottomRight:nth-last-of-type(86){bottom:2150px;transform:scale(.96);z-index:9913;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(87),:host.growlBottomRight:nth-last-of-type(87){bottom:2175px;transform:scale(.96);z-index:9912;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(88),:host.growlBottomRight:nth-last-of-type(88){bottom:2200px;transform:scale(.96);z-index:9911;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(89),:host.growlBottomRight:nth-last-of-type(89){bottom:2225px;transform:scale(.96);z-index:9910;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(90),:host.growlBottomRight:nth-last-of-type(90){bottom:2250px;transform:scale(.96);z-index:9909;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(91),:host.growlBottomRight:nth-last-of-type(91){bottom:2275px;transform:scale(.96);z-index:9908;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(92),:host.growlBottomRight:nth-last-of-type(92){bottom:2300px;transform:scale(.96);z-index:9907;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(93),:host.growlBottomRight:nth-last-of-type(93){bottom:2325px;transform:scale(.96);z-index:9906;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(94),:host.growlBottomRight:nth-last-of-type(94){bottom:2350px;transform:scale(.96);z-index:9905;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(95),:host.growlBottomRight:nth-last-of-type(95){bottom:2375px;transform:scale(.96);z-index:9904;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(96),:host.growlBottomRight:nth-last-of-type(96){bottom:2400px;transform:scale(.96);z-index:9903;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(97),:host.growlBottomRight:nth-last-of-type(97){bottom:2425px;transform:scale(.96);z-index:9902;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(98),:host.growlBottomRight:nth-last-of-type(98){bottom:2450px;transform:scale(.96);z-index:9901;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(99),:host.growlBottomRight:nth-last-of-type(99){bottom:2475px;transform:scale(.96);z-index:9900;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(100),:host.growlBottomRight:nth-last-of-type(100){bottom:2500px;transform:scale(.96);z-index:9899;filter:brightness(.8571428571)}:host.growlBottomLeft:last-of-type,:host.growlBottomRight:last-of-type,:host.growlTopLeft:last-of-type,:host.growlTopRight:last-of-type{box-shadow:0 1px 3px #00000080}:host.growlBottomRight,:host.growlTopRight{right:-100%;left:auto;width:calc(100% - 30px);transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomRight.animate,:host.growlTopRight.animate{right:1rem}:host:not(.launched){animation:embedded-slide-in .2s ease-in-out}:host.dialogue .toast-content{display:flex;flex-direction:row!important;align-items:center}:host.dialogue p.message-only{flex:3 0 0}:host.dialogue .dialogue{display:inherit}:host.black{color:#fff;background:#000}:host.novo-accent-black{border:1px solid #000000;background:#e6e6e6;color:#3d464d}:host.white{color:#3d464d;background:#fff}:host.novo-accent-white{border:1px solid #ffffff;background:#e6e6e6;color:#3d464d}:host.gray{color:#3d464d;background:#9e9e9e}:host.novo-accent-gray{border:1px solid #9e9e9e;background:#e6e6e6;color:#3d464d}:host.grey{color:#3d464d;background:#9e9e9e}:host.novo-accent-grey{border:1px solid #9e9e9e;background:#e6e6e6;color:#3d464d}:host.offWhite{color:#3d464d;background:#f7f7f7}:host.novo-accent-offWhite{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.bright{color:#3d464d;background:#f7f7f7}:host.novo-accent-bright{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.light{color:#3d464d;background:#dbdbdb}:host.novo-accent-light{border:1px solid #dbdbdb;background:#e6e6e6;color:#3d464d}:host.neutral{color:#fff;background:#4f5361}:host.novo-accent-neutral{border:1px solid #4f5361;background:#e3e4e8;color:#3d464d}:host.dark{color:#fff;background:#3d464d}:host.novo-accent-dark{border:1px solid #3d464d;background:#e3e6e8;color:#3d464d}:host.orange{color:#3d464d;background:#ff6900}:host.novo-accent-orange{border:1px solid #ff6900;background:#ffe1cc;color:#3d464d}:host.navigation{color:#fff;background:#202945}:host.novo-accent-navigation{border:1px solid #202945;background:#dce1ef;color:#3d464d}:host.skyBlue{color:#fff;background:#009bdf}:host.novo-accent-skyBlue{border:1px solid #009bdf;background:#ccefff;color:#3d464d}:host.steel{color:#fff;background:#5b6770}:host.novo-accent-steel{border:1px solid #5b6770;background:#e3e6e8;color:#3d464d}:host.metal{color:#fff;background:#637893}:host.novo-accent-metal{border:1px solid #637893;background:#e1e5ea;color:#3d464d}:host.sand{color:#3d464d;background:#f4f4f4}:host.novo-accent-sand{border:1px solid #f4f4f4;background:#e6e6e6;color:#3d464d}:host.silver{color:#3d464d;background:#e2e2e2}:host.novo-accent-silver{border:1px solid #e2e2e2;background:#e6e6e6;color:#3d464d}:host.stone{color:#3d464d;background:#bebebe}:host.novo-accent-stone{border:1px solid #bebebe;background:#e6e6e6;color:#3d464d}:host.ash{color:#3d464d;background:#a0a0a0}:host.novo-accent-ash{border:1px solid #a0a0a0;background:#e6e6e6;color:#3d464d}:host.slate{color:#fff;background:#707070}:host.novo-accent-slate{border:1px solid #707070;background:#e6e6e6;color:#3d464d}:host.onyx{color:#fff;background:#526980}:host.novo-accent-onyx{border:1px solid #526980;background:#e0e6eb;color:#3d464d}:host.charcoal{color:#fff;background:#282828}:host.novo-accent-charcoal{border:1px solid #282828;background:#e6e6e6;color:#3d464d}:host.moonlight{color:#fff;background:#1a242f}:host.novo-accent-moonlight{border:1px solid #1a242f;background:#dee5ed;color:#3d464d}:host.midnight{color:#fff;background:#202945}:host.novo-accent-midnight{border:1px solid #202945;background:#dce1ef;color:#3d464d}:host.darkness{color:#fff;background:#161f27}:host.novo-accent-darkness{border:1px solid #161f27;background:#dee6ed;color:#3d464d}:host.navy{color:#fff;background:#0d2d42}:host.novo-accent-navy{border:1px solid #0d2d42;background:#d4e9f7;color:#3d464d}:host.aqua{color:#3d464d;background:#3bafda}:host.novo-accent-aqua{border:1px solid #3bafda;background:#d4edf7;color:#3d464d}:host.ocean{color:#fff;background:#4a89dc}:host.novo-accent-ocean{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.mint{color:#3d464d;background:#37bc9b}:host.novo-accent-mint{border:1px solid #37bc9b;background:#d8f3ed;color:#3d464d}:host.grass{color:#fff;background:#8cc152}:host.novo-accent-grass{border:1px solid #8cc152;background:#e6f2d9;color:#3d464d}:host.sunflower{color:#fff;background:#f6b042}:host.novo-accent-sunflower{border:1px solid #f6b042;background:#fdebce;color:#3d464d}:host.bittersweet{color:#fff;background:#eb6845}:host.novo-accent-bittersweet{border:1px solid #eb6845;background:#fadad1;color:#3d464d}:host.grapefruit{color:#fff;background:#da4453}:host.novo-accent-grapefruit{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.carnation{color:#fff;background:#d770ad}:host.novo-accent-carnation{border:1px solid #d770ad;background:#f4d7e8;color:#3d464d}:host.lavender{color:#fff;background:#967adc}:host.novo-accent-lavender{border:1px solid #967adc;background:#dfd7f4;color:#3d464d}:host.mountain{color:#fff;background:#9678b6}:host.novo-accent-mountain{border:1px solid #9678b6;background:#e5deed;color:#3d464d}:host.info{color:#fff;background:#4a89dc}:host.novo-accent-info{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.positive{color:#fff;background:#4a89dc}:host.novo-accent-positive{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.success{color:#fff;background:#8cc152}:host.novo-accent-success{border:1px solid #8cc152;background:#e6f2d9;color:#3d464d}:host.negative{color:#fff;background:#da4453}:host.novo-accent-negative{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.danger{color:#fff;background:#da4453}:host.novo-accent-danger{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.error{color:#fff;background:#da4453}:host.novo-accent-error{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.warning{color:#fff;background:#f6b042}:host.novo-accent-warning{border:1px solid #f6b042;background:#fdebce;color:#3d464d}:host.empty{color:#3d464d;background:#cccdcc}:host.novo-accent-empty{border:1px solid #cccdcc;background:#e5e6e5;color:#3d464d}:host.disabled{color:#3d464d;background:#bebebe}:host.novo-accent-disabled{border:1px solid #bebebe;background:#e6e6e6;color:#3d464d}:host.background{color:#3d464d;background:#f7f7f7}:host.novo-accent-background{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.backgroundDark{color:#3d464d;background:#e2e2e2}:host.novo-accent-backgroundDark{border:1px solid #e2e2e2;background:#e6e6e6;color:#3d464d}:host.presentation{color:#fff;background:#5b6770}:host.novo-accent-presentation{border:1px solid #5b6770;background:#e3e6e8;color:#3d464d}:host.bullhorn{color:#3d464d;background:#ff6900}:host.novo-accent-bullhorn{border:1px solid #ff6900;background:#ffe1cc;color:#3d464d}:host.pulse{color:#3d464d;background:#3bafda}:host.novo-accent-pulse{border:1px solid #3bafda;background:#d4edf7;color:#3d464d}:host.company{color:#fff;background:#39d}:host.novo-accent-company{border:1px solid #3399dd;background:#d3e9f8;color:#3d464d}:host.candidate{color:#fff;background:#4b7}:host.novo-accent-candidate{border:1px solid #44bb77;background:#daf1e4;color:#3d464d}:host.lead{color:#fff;background:#a69}:host.novo-accent-lead{border:1px solid #aa6699;background:#eddee9;color:#3d464d}:host.contact{color:#fff;background:#fa4}:host.novo-accent-contact{border:1px solid #ffaa44;background:#ffe8cc;color:#3d464d}:host.clientcontact{color:#fff;background:#fa4}:host.novo-accent-clientcontact{border:1px solid #ffaa44;background:#ffe8cc;color:#3d464d}:host.opportunity{color:#fff;background:#625}:host.novo-accent-opportunity{border:1px solid #662255;background:#f2d9ec;color:#3d464d}:host.job{color:#fff;background:#b56}:host.novo-accent-job{border:1px solid #bb5566;background:#f0dbde;color:#3d464d}:host.joborder{color:#fff;background:#b56}:host.novo-accent-joborder{border:1px solid #bb5566;background:#f0dbde;color:#3d464d}:host.submission{color:#3d464d;background:#a9adbb}:host.novo-accent-submission{border:1px solid #a9adbb;background:#e3e4e8;color:#3d464d}:host.sendout{color:#fff;background:#747884}:host.novo-accent-sendout{border:1px solid #747884;background:#e4e5e7;color:#3d464d}:host.placement{color:#fff;background:#0b344f}:host.novo-accent-placement{border:1px solid #0b344f;background:#d2e9f9;color:#3d464d}:host.note{color:#fff;background:#747884}:host.novo-accent-note{border:1px solid #747884;background:#e4e5e7;color:#3d464d}:host.contract{color:#fff;background:#454ea0}:host.novo-accent-contract{border:1px solid #454ea0;background:#dbddf0;color:#3d464d}:host.jobCode{color:#fff;background:#696d79}:host.novo-accent-jobCode{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.earnCode{color:#fff;background:#696d79}:host.novo-accent-earnCode{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.invoiceStatement{color:#fff;background:#696d79}:host.novo-accent-invoiceStatement{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.billableCharge{color:#fff;background:#696d79}:host.novo-accent-billableCharge{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.payableCharge{color:#fff;background:#696d79}:host.novo-accent-payableCharge{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.user{color:#fff;background:#696d79}:host.novo-accent-user{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.corporateUser{color:#fff;background:#696d79}:host.novo-accent-corporateUser{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.distributionList{color:#fff;background:#696d79}:host.novo-accent-distributionList{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.credential{color:#fff;background:#696d79}:host.novo-accent-credential{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.person{color:#fff;background:#696d79}:host.novo-accent-person{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}@keyframes embedded-slide-in{0%{transform:translateY(-100%);opacity:0}to{transform:translateY(0);opacity:1}}@media screen and (min-width: 350px){:host[class*=growl]{min-width:350px}:host.growlBottomLeft,:host.growlTopLeft{left:-100%;right:auto;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomLeft.animate,:host.growlTopLeft.animate{left:1rem}:host.growlBottomRight,:host.growlTopRight{right:-100%;left:auto;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomRight.animate,:host.growlTopRight.animate{right:1rem}}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i3.NovoButtonElement, selector: "novo-button,button[theme]", inputs: ["color", "side", "size", "theme", "loading", "icon", "secondIcon", "disabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastElement, decorators: [{
            type: Component,
            args: [{ selector: 'novo-toast', host: {
                        '[class]': 'alertTheme',
                        '[class.growl]': 'appearance == "growl"',
                        '[class.banner]': 'appearance == "banner"',
                        '[class.show]': 'show',
                        '[class.animate]': 'animate',
                        '[class.embedded]': 'embedded',
                        '[attr.theme]': 'theme',
                        '(click)': '!isCloseable && clickHandler($event)',
                    }, template: `
    <div class="toast-icon">
      <i [ngClass]="iconClass"></i>
    </div>
    <div class="toast-content">
      <h5 *ngIf="title">{{ title }}</h5>
      <p *ngIf="_message" [class.message-only]="!title" [innerHtml]="_message"></p>
      <div *ngIf="link" class="link-generated">
        <input type="text" [value]="link" onfocus="this.select();" />
      </div>
      <div class="dialogue">
        <ng-content></ng-content>
      </div>
      <div *ngIf="action" class="action">
        <button theme="dialogue" color="white" (click)="actionHandler($event)">{{ action }}</button>
      </div>
    </div>
    <div class="close-icon" *ngIf="isCloseable" (click)="close($event)">
      <i class="bhi-times"></i>
    </div>
  `, styles: [":host{display:grid;grid-template-columns:5rem 1fr 15px;justify-content:flex-start;align-content:center;align-items:center;position:relative;background:#0d2d42;color:#fff;padding:1rem;box-shadow:0 1px 3px #00000026}:host.show{display:grid!important}:host.launched{display:none;position:fixed;z-index:9999}:host .toast-icon{display:flex;justify-content:center;align-content:center;align-items:center;width:32px;height:32px;background:#00000026;border-radius:3px}:host .close-icon{display:flex;justify-content:center;align-content:center;align-items:center;align-self:flex-start;cursor:pointer;height:100%}:host .toast-icon i,:host .close-icon i{display:flex;position:relative;font-size:1.2rem;line-height:1.2}:host.toast-container .toast-content .link-generated{width:100%;position:relative}:host.toast-container .toast-content .link-generated input{background:transparent!important;border:none;border-bottom:1px solid #afb9c0;border-radius:0;outline:none;height:2rem;width:95%;margin:0;padding:0;box-shadow:none;box-sizing:content-box;transition:all .3s;color:#fff;text-overflow:ellipsis}:host.toast-container .toast-content .link-generated input:focus{background-color:#4a89dc}:host.toast-container .toast-content .link-generated input:hover{border-bottom:1px solid #5f6d78}:host p{white-space:pre-line}:host h5{display:block;font-size:1.4rem;color:inherit}:host .toast-content>p{margin:0;max-width:inherit;font-size:1.3rem}:host .toast-content>p.message-only{padding:0;font-size:1.4rem}:host.text{background:#3d464d}:host.neutral{background:#4f5361}:host.background{background:#f7f7f7}:host.background .toast-content>h5{color:#3d464d!important}:host.background i,:host.background p{color:#3d464d}:host.fixedBottom,:host.fixedTop{left:0;right:0}:host.fixedBottom{bottom:-100%;padding-bottom:20px;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.fixedBottom.animate{padding-bottom:10px;bottom:0}:host.fixedBottom:nth-last-of-type(2){bottom:25px;z-index:9997;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(3){bottom:50px;z-index:9996;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(4){bottom:75px;z-index:9995;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(5){bottom:100px;z-index:9994;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(6){bottom:125px;z-index:9993;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(7){bottom:150px;z-index:9992;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(8){bottom:175px;z-index:9991;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(9){bottom:200px;z-index:9990;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(10){bottom:225px;z-index:9989;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(11){bottom:250px;z-index:9988;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(12){bottom:275px;z-index:9987;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(13){bottom:300px;z-index:9986;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(14){bottom:325px;z-index:9985;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(15){bottom:350px;z-index:9984;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(16){bottom:375px;z-index:9983;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(17){bottom:400px;z-index:9982;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(18){bottom:425px;z-index:9981;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(19){bottom:450px;z-index:9980;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(20){bottom:475px;z-index:9979;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(21){bottom:500px;z-index:9978;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(22){bottom:525px;z-index:9977;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(23){bottom:550px;z-index:9976;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(24){bottom:575px;z-index:9975;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(25){bottom:600px;z-index:9974;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(26){bottom:625px;z-index:9973;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(27){bottom:650px;z-index:9972;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(28){bottom:675px;z-index:9971;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(29){bottom:700px;z-index:9970;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(30){bottom:725px;z-index:9969;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(31){bottom:750px;z-index:9968;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(32){bottom:775px;z-index:9967;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(33){bottom:800px;z-index:9966;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(34){bottom:825px;z-index:9965;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(35){bottom:850px;z-index:9964;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(36){bottom:875px;z-index:9963;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(37){bottom:900px;z-index:9962;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(38){bottom:925px;z-index:9961;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(39){bottom:950px;z-index:9960;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(40){bottom:975px;z-index:9959;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(41){bottom:1000px;z-index:9958;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(42){bottom:1025px;z-index:9957;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(43){bottom:1050px;z-index:9956;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(44){bottom:1075px;z-index:9955;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(45){bottom:1100px;z-index:9954;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(46){bottom:1125px;z-index:9953;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(47){bottom:1150px;z-index:9952;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(48){bottom:1175px;z-index:9951;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(49){bottom:1200px;z-index:9950;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(50){bottom:1225px;z-index:9949;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(51){bottom:1250px;z-index:9948;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(52){bottom:1275px;z-index:9947;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(53){bottom:1300px;z-index:9946;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(54){bottom:1325px;z-index:9945;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(55){bottom:1350px;z-index:9944;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(56){bottom:1375px;z-index:9943;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(57){bottom:1400px;z-index:9942;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(58){bottom:1425px;z-index:9941;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(59){bottom:1450px;z-index:9940;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(60){bottom:1475px;z-index:9939;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(61){bottom:1500px;z-index:9938;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(62){bottom:1525px;z-index:9937;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(63){bottom:1550px;z-index:9936;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(64){bottom:1575px;z-index:9935;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(65){bottom:1600px;z-index:9934;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(66){bottom:1625px;z-index:9933;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(67){bottom:1650px;z-index:9932;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(68){bottom:1675px;z-index:9931;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(69){bottom:1700px;z-index:9930;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(70){bottom:1725px;z-index:9929;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(71){bottom:1750px;z-index:9928;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(72){bottom:1775px;z-index:9927;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(73){bottom:1800px;z-index:9926;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(74){bottom:1825px;z-index:9925;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(75){bottom:1850px;z-index:9924;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(76){bottom:1875px;z-index:9923;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(77){bottom:1900px;z-index:9922;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(78){bottom:1925px;z-index:9921;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(79){bottom:1950px;z-index:9920;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(80){bottom:1975px;z-index:9919;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(81){bottom:2000px;z-index:9918;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(82){bottom:2025px;z-index:9917;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(83){bottom:2050px;z-index:9916;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(84){bottom:2075px;z-index:9915;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(85){bottom:2100px;z-index:9914;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(86){bottom:2125px;z-index:9913;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(87){bottom:2150px;z-index:9912;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(88){bottom:2175px;z-index:9911;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(89){bottom:2200px;z-index:9910;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(90){bottom:2225px;z-index:9909;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(91){bottom:2250px;z-index:9908;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(92){bottom:2275px;z-index:9907;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(93){bottom:2300px;z-index:9906;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(94){bottom:2325px;z-index:9905;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(95){bottom:2350px;z-index:9904;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(96){bottom:2375px;z-index:9903;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(97){bottom:2400px;z-index:9902;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(98){bottom:2425px;z-index:9901;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(99){bottom:2450px;z-index:9900;filter:brightness(.8571428571)}:host.fixedBottom:nth-last-of-type(100){bottom:2475px;z-index:9899;filter:brightness(.8571428571)}:host.fixedTop{top:-100%;padding-top:20px;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.fixedTop.animate{padding-top:10px;top:0}:host.fixedTop:nth-last-of-type(2){top:25px;z-index:9997;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(3){top:50px;z-index:9996;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(4){top:75px;z-index:9995;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(5){top:100px;z-index:9994;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(6){top:125px;z-index:9993;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(7){top:150px;z-index:9992;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(8){top:175px;z-index:9991;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(9){top:200px;z-index:9990;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(10){top:225px;z-index:9989;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(11){top:250px;z-index:9988;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(12){top:275px;z-index:9987;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(13){top:300px;z-index:9986;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(14){top:325px;z-index:9985;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(15){top:350px;z-index:9984;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(16){top:375px;z-index:9983;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(17){top:400px;z-index:9982;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(18){top:425px;z-index:9981;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(19){top:450px;z-index:9980;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(20){top:475px;z-index:9979;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(21){top:500px;z-index:9978;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(22){top:525px;z-index:9977;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(23){top:550px;z-index:9976;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(24){top:575px;z-index:9975;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(25){top:600px;z-index:9974;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(26){top:625px;z-index:9973;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(27){top:650px;z-index:9972;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(28){top:675px;z-index:9971;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(29){top:700px;z-index:9970;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(30){top:725px;z-index:9969;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(31){top:750px;z-index:9968;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(32){top:775px;z-index:9967;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(33){top:800px;z-index:9966;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(34){top:825px;z-index:9965;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(35){top:850px;z-index:9964;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(36){top:875px;z-index:9963;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(37){top:900px;z-index:9962;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(38){top:925px;z-index:9961;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(39){top:950px;z-index:9960;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(40){top:975px;z-index:9959;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(41){top:1000px;z-index:9958;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(42){top:1025px;z-index:9957;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(43){top:1050px;z-index:9956;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(44){top:1075px;z-index:9955;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(45){top:1100px;z-index:9954;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(46){top:1125px;z-index:9953;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(47){top:1150px;z-index:9952;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(48){top:1175px;z-index:9951;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(49){top:1200px;z-index:9950;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(50){top:1225px;z-index:9949;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(51){top:1250px;z-index:9948;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(52){top:1275px;z-index:9947;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(53){top:1300px;z-index:9946;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(54){top:1325px;z-index:9945;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(55){top:1350px;z-index:9944;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(56){top:1375px;z-index:9943;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(57){top:1400px;z-index:9942;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(58){top:1425px;z-index:9941;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(59){top:1450px;z-index:9940;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(60){top:1475px;z-index:9939;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(61){top:1500px;z-index:9938;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(62){top:1525px;z-index:9937;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(63){top:1550px;z-index:9936;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(64){top:1575px;z-index:9935;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(65){top:1600px;z-index:9934;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(66){top:1625px;z-index:9933;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(67){top:1650px;z-index:9932;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(68){top:1675px;z-index:9931;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(69){top:1700px;z-index:9930;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(70){top:1725px;z-index:9929;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(71){top:1750px;z-index:9928;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(72){top:1775px;z-index:9927;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(73){top:1800px;z-index:9926;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(74){top:1825px;z-index:9925;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(75){top:1850px;z-index:9924;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(76){top:1875px;z-index:9923;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(77){top:1900px;z-index:9922;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(78){top:1925px;z-index:9921;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(79){top:1950px;z-index:9920;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(80){top:1975px;z-index:9919;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(81){top:2000px;z-index:9918;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(82){top:2025px;z-index:9917;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(83){top:2050px;z-index:9916;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(84){top:2075px;z-index:9915;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(85){top:2100px;z-index:9914;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(86){top:2125px;z-index:9913;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(87){top:2150px;z-index:9912;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(88){top:2175px;z-index:9911;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(89){top:2200px;z-index:9910;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(90){top:2225px;z-index:9909;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(91){top:2250px;z-index:9908;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(92){top:2275px;z-index:9907;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(93){top:2300px;z-index:9906;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(94){top:2325px;z-index:9905;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(95){top:2350px;z-index:9904;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(96){top:2375px;z-index:9903;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(97){top:2400px;z-index:9902;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(98){top:2425px;z-index:9901;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(99){top:2450px;z-index:9900;filter:brightness(.8571428571)}:host.fixedTop:nth-last-of-type(100){top:2475px;z-index:9899;filter:brightness(.8571428571)}:host.embedded.fixedBottom,:host.embedded.fixedTop{top:auto;left:auto;right:auto;width:inherit;margin:-1rem -3rem}:host.embedded.fixedBottom.animate,:host.embedded.fixedTop.animate{top:auto}:host[class*=growl]{border-radius:3px;max-width:350px}:host.growlBottomLeft,:host.growlTopLeft{left:-100%;right:auto;width:calc(100% - 30px);transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomLeft.animate,:host.growlTopLeft.animate{left:15px}:host.growlTopLeft,:host.growlTopRight{top:1rem}:host.growlTopLeft:nth-last-of-type(2),:host.growlTopRight:nth-last-of-type(2){top:50px;transform:scale(.96);z-index:9997;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(3),:host.growlTopRight:nth-last-of-type(3){top:75px;transform:scale(.96);z-index:9996;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(4),:host.growlTopRight:nth-last-of-type(4){top:100px;transform:scale(.96);z-index:9995;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(5),:host.growlTopRight:nth-last-of-type(5){top:125px;transform:scale(.96);z-index:9994;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(6),:host.growlTopRight:nth-last-of-type(6){top:150px;transform:scale(.96);z-index:9993;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(7),:host.growlTopRight:nth-last-of-type(7){top:175px;transform:scale(.96);z-index:9992;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(8),:host.growlTopRight:nth-last-of-type(8){top:200px;transform:scale(.96);z-index:9991;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(9),:host.growlTopRight:nth-last-of-type(9){top:225px;transform:scale(.96);z-index:9990;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(10),:host.growlTopRight:nth-last-of-type(10){top:250px;transform:scale(.96);z-index:9989;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(11),:host.growlTopRight:nth-last-of-type(11){top:275px;transform:scale(.96);z-index:9988;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(12),:host.growlTopRight:nth-last-of-type(12){top:300px;transform:scale(.96);z-index:9987;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(13),:host.growlTopRight:nth-last-of-type(13){top:325px;transform:scale(.96);z-index:9986;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(14),:host.growlTopRight:nth-last-of-type(14){top:350px;transform:scale(.96);z-index:9985;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(15),:host.growlTopRight:nth-last-of-type(15){top:375px;transform:scale(.96);z-index:9984;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(16),:host.growlTopRight:nth-last-of-type(16){top:400px;transform:scale(.96);z-index:9983;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(17),:host.growlTopRight:nth-last-of-type(17){top:425px;transform:scale(.96);z-index:9982;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(18),:host.growlTopRight:nth-last-of-type(18){top:450px;transform:scale(.96);z-index:9981;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(19),:host.growlTopRight:nth-last-of-type(19){top:475px;transform:scale(.96);z-index:9980;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(20),:host.growlTopRight:nth-last-of-type(20){top:500px;transform:scale(.96);z-index:9979;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(21),:host.growlTopRight:nth-last-of-type(21){top:525px;transform:scale(.96);z-index:9978;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(22),:host.growlTopRight:nth-last-of-type(22){top:550px;transform:scale(.96);z-index:9977;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(23),:host.growlTopRight:nth-last-of-type(23){top:575px;transform:scale(.96);z-index:9976;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(24),:host.growlTopRight:nth-last-of-type(24){top:600px;transform:scale(.96);z-index:9975;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(25),:host.growlTopRight:nth-last-of-type(25){top:625px;transform:scale(.96);z-index:9974;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(26),:host.growlTopRight:nth-last-of-type(26){top:650px;transform:scale(.96);z-index:9973;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(27),:host.growlTopRight:nth-last-of-type(27){top:675px;transform:scale(.96);z-index:9972;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(28),:host.growlTopRight:nth-last-of-type(28){top:700px;transform:scale(.96);z-index:9971;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(29),:host.growlTopRight:nth-last-of-type(29){top:725px;transform:scale(.96);z-index:9970;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(30),:host.growlTopRight:nth-last-of-type(30){top:750px;transform:scale(.96);z-index:9969;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(31),:host.growlTopRight:nth-last-of-type(31){top:775px;transform:scale(.96);z-index:9968;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(32),:host.growlTopRight:nth-last-of-type(32){top:800px;transform:scale(.96);z-index:9967;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(33),:host.growlTopRight:nth-last-of-type(33){top:825px;transform:scale(.96);z-index:9966;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(34),:host.growlTopRight:nth-last-of-type(34){top:850px;transform:scale(.96);z-index:9965;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(35),:host.growlTopRight:nth-last-of-type(35){top:875px;transform:scale(.96);z-index:9964;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(36),:host.growlTopRight:nth-last-of-type(36){top:900px;transform:scale(.96);z-index:9963;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(37),:host.growlTopRight:nth-last-of-type(37){top:925px;transform:scale(.96);z-index:9962;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(38),:host.growlTopRight:nth-last-of-type(38){top:950px;transform:scale(.96);z-index:9961;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(39),:host.growlTopRight:nth-last-of-type(39){top:975px;transform:scale(.96);z-index:9960;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(40),:host.growlTopRight:nth-last-of-type(40){top:1000px;transform:scale(.96);z-index:9959;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(41),:host.growlTopRight:nth-last-of-type(41){top:1025px;transform:scale(.96);z-index:9958;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(42),:host.growlTopRight:nth-last-of-type(42){top:1050px;transform:scale(.96);z-index:9957;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(43),:host.growlTopRight:nth-last-of-type(43){top:1075px;transform:scale(.96);z-index:9956;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(44),:host.growlTopRight:nth-last-of-type(44){top:1100px;transform:scale(.96);z-index:9955;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(45),:host.growlTopRight:nth-last-of-type(45){top:1125px;transform:scale(.96);z-index:9954;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(46),:host.growlTopRight:nth-last-of-type(46){top:1150px;transform:scale(.96);z-index:9953;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(47),:host.growlTopRight:nth-last-of-type(47){top:1175px;transform:scale(.96);z-index:9952;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(48),:host.growlTopRight:nth-last-of-type(48){top:1200px;transform:scale(.96);z-index:9951;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(49),:host.growlTopRight:nth-last-of-type(49){top:1225px;transform:scale(.96);z-index:9950;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(50),:host.growlTopRight:nth-last-of-type(50){top:1250px;transform:scale(.96);z-index:9949;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(51),:host.growlTopRight:nth-last-of-type(51){top:1275px;transform:scale(.96);z-index:9948;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(52),:host.growlTopRight:nth-last-of-type(52){top:1300px;transform:scale(.96);z-index:9947;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(53),:host.growlTopRight:nth-last-of-type(53){top:1325px;transform:scale(.96);z-index:9946;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(54),:host.growlTopRight:nth-last-of-type(54){top:1350px;transform:scale(.96);z-index:9945;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(55),:host.growlTopRight:nth-last-of-type(55){top:1375px;transform:scale(.96);z-index:9944;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(56),:host.growlTopRight:nth-last-of-type(56){top:1400px;transform:scale(.96);z-index:9943;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(57),:host.growlTopRight:nth-last-of-type(57){top:1425px;transform:scale(.96);z-index:9942;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(58),:host.growlTopRight:nth-last-of-type(58){top:1450px;transform:scale(.96);z-index:9941;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(59),:host.growlTopRight:nth-last-of-type(59){top:1475px;transform:scale(.96);z-index:9940;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(60),:host.growlTopRight:nth-last-of-type(60){top:1500px;transform:scale(.96);z-index:9939;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(61),:host.growlTopRight:nth-last-of-type(61){top:1525px;transform:scale(.96);z-index:9938;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(62),:host.growlTopRight:nth-last-of-type(62){top:1550px;transform:scale(.96);z-index:9937;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(63),:host.growlTopRight:nth-last-of-type(63){top:1575px;transform:scale(.96);z-index:9936;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(64),:host.growlTopRight:nth-last-of-type(64){top:1600px;transform:scale(.96);z-index:9935;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(65),:host.growlTopRight:nth-last-of-type(65){top:1625px;transform:scale(.96);z-index:9934;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(66),:host.growlTopRight:nth-last-of-type(66){top:1650px;transform:scale(.96);z-index:9933;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(67),:host.growlTopRight:nth-last-of-type(67){top:1675px;transform:scale(.96);z-index:9932;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(68),:host.growlTopRight:nth-last-of-type(68){top:1700px;transform:scale(.96);z-index:9931;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(69),:host.growlTopRight:nth-last-of-type(69){top:1725px;transform:scale(.96);z-index:9930;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(70),:host.growlTopRight:nth-last-of-type(70){top:1750px;transform:scale(.96);z-index:9929;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(71),:host.growlTopRight:nth-last-of-type(71){top:1775px;transform:scale(.96);z-index:9928;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(72),:host.growlTopRight:nth-last-of-type(72){top:1800px;transform:scale(.96);z-index:9927;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(73),:host.growlTopRight:nth-last-of-type(73){top:1825px;transform:scale(.96);z-index:9926;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(74),:host.growlTopRight:nth-last-of-type(74){top:1850px;transform:scale(.96);z-index:9925;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(75),:host.growlTopRight:nth-last-of-type(75){top:1875px;transform:scale(.96);z-index:9924;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(76),:host.growlTopRight:nth-last-of-type(76){top:1900px;transform:scale(.96);z-index:9923;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(77),:host.growlTopRight:nth-last-of-type(77){top:1925px;transform:scale(.96);z-index:9922;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(78),:host.growlTopRight:nth-last-of-type(78){top:1950px;transform:scale(.96);z-index:9921;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(79),:host.growlTopRight:nth-last-of-type(79){top:1975px;transform:scale(.96);z-index:9920;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(80),:host.growlTopRight:nth-last-of-type(80){top:2000px;transform:scale(.96);z-index:9919;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(81),:host.growlTopRight:nth-last-of-type(81){top:2025px;transform:scale(.96);z-index:9918;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(82),:host.growlTopRight:nth-last-of-type(82){top:2050px;transform:scale(.96);z-index:9917;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(83),:host.growlTopRight:nth-last-of-type(83){top:2075px;transform:scale(.96);z-index:9916;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(84),:host.growlTopRight:nth-last-of-type(84){top:2100px;transform:scale(.96);z-index:9915;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(85),:host.growlTopRight:nth-last-of-type(85){top:2125px;transform:scale(.96);z-index:9914;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(86),:host.growlTopRight:nth-last-of-type(86){top:2150px;transform:scale(.96);z-index:9913;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(87),:host.growlTopRight:nth-last-of-type(87){top:2175px;transform:scale(.96);z-index:9912;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(88),:host.growlTopRight:nth-last-of-type(88){top:2200px;transform:scale(.96);z-index:9911;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(89),:host.growlTopRight:nth-last-of-type(89){top:2225px;transform:scale(.96);z-index:9910;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(90),:host.growlTopRight:nth-last-of-type(90){top:2250px;transform:scale(.96);z-index:9909;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(91),:host.growlTopRight:nth-last-of-type(91){top:2275px;transform:scale(.96);z-index:9908;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(92),:host.growlTopRight:nth-last-of-type(92){top:2300px;transform:scale(.96);z-index:9907;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(93),:host.growlTopRight:nth-last-of-type(93){top:2325px;transform:scale(.96);z-index:9906;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(94),:host.growlTopRight:nth-last-of-type(94){top:2350px;transform:scale(.96);z-index:9905;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(95),:host.growlTopRight:nth-last-of-type(95){top:2375px;transform:scale(.96);z-index:9904;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(96),:host.growlTopRight:nth-last-of-type(96){top:2400px;transform:scale(.96);z-index:9903;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(97),:host.growlTopRight:nth-last-of-type(97){top:2425px;transform:scale(.96);z-index:9902;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(98),:host.growlTopRight:nth-last-of-type(98){top:2450px;transform:scale(.96);z-index:9901;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(99),:host.growlTopRight:nth-last-of-type(99){top:2475px;transform:scale(.96);z-index:9900;filter:brightness(.8571428571)}:host.growlTopLeft:nth-last-of-type(100),:host.growlTopRight:nth-last-of-type(100){top:2500px;transform:scale(.96);z-index:9899;filter:brightness(.8571428571)}:host.growlBottomLeft,:host.growlBottomRight{bottom:1rem}:host.growlBottomLeft:nth-last-of-type(2),:host.growlBottomRight:nth-last-of-type(2){bottom:50px;transform:scale(.96);z-index:9997;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(3),:host.growlBottomRight:nth-last-of-type(3){bottom:75px;transform:scale(.96);z-index:9996;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(4),:host.growlBottomRight:nth-last-of-type(4){bottom:100px;transform:scale(.96);z-index:9995;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(5),:host.growlBottomRight:nth-last-of-type(5){bottom:125px;transform:scale(.96);z-index:9994;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(6),:host.growlBottomRight:nth-last-of-type(6){bottom:150px;transform:scale(.96);z-index:9993;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(7),:host.growlBottomRight:nth-last-of-type(7){bottom:175px;transform:scale(.96);z-index:9992;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(8),:host.growlBottomRight:nth-last-of-type(8){bottom:200px;transform:scale(.96);z-index:9991;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(9),:host.growlBottomRight:nth-last-of-type(9){bottom:225px;transform:scale(.96);z-index:9990;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(10),:host.growlBottomRight:nth-last-of-type(10){bottom:250px;transform:scale(.96);z-index:9989;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(11),:host.growlBottomRight:nth-last-of-type(11){bottom:275px;transform:scale(.96);z-index:9988;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(12),:host.growlBottomRight:nth-last-of-type(12){bottom:300px;transform:scale(.96);z-index:9987;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(13),:host.growlBottomRight:nth-last-of-type(13){bottom:325px;transform:scale(.96);z-index:9986;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(14),:host.growlBottomRight:nth-last-of-type(14){bottom:350px;transform:scale(.96);z-index:9985;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(15),:host.growlBottomRight:nth-last-of-type(15){bottom:375px;transform:scale(.96);z-index:9984;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(16),:host.growlBottomRight:nth-last-of-type(16){bottom:400px;transform:scale(.96);z-index:9983;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(17),:host.growlBottomRight:nth-last-of-type(17){bottom:425px;transform:scale(.96);z-index:9982;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(18),:host.growlBottomRight:nth-last-of-type(18){bottom:450px;transform:scale(.96);z-index:9981;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(19),:host.growlBottomRight:nth-last-of-type(19){bottom:475px;transform:scale(.96);z-index:9980;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(20),:host.growlBottomRight:nth-last-of-type(20){bottom:500px;transform:scale(.96);z-index:9979;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(21),:host.growlBottomRight:nth-last-of-type(21){bottom:525px;transform:scale(.96);z-index:9978;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(22),:host.growlBottomRight:nth-last-of-type(22){bottom:550px;transform:scale(.96);z-index:9977;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(23),:host.growlBottomRight:nth-last-of-type(23){bottom:575px;transform:scale(.96);z-index:9976;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(24),:host.growlBottomRight:nth-last-of-type(24){bottom:600px;transform:scale(.96);z-index:9975;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(25),:host.growlBottomRight:nth-last-of-type(25){bottom:625px;transform:scale(.96);z-index:9974;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(26),:host.growlBottomRight:nth-last-of-type(26){bottom:650px;transform:scale(.96);z-index:9973;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(27),:host.growlBottomRight:nth-last-of-type(27){bottom:675px;transform:scale(.96);z-index:9972;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(28),:host.growlBottomRight:nth-last-of-type(28){bottom:700px;transform:scale(.96);z-index:9971;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(29),:host.growlBottomRight:nth-last-of-type(29){bottom:725px;transform:scale(.96);z-index:9970;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(30),:host.growlBottomRight:nth-last-of-type(30){bottom:750px;transform:scale(.96);z-index:9969;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(31),:host.growlBottomRight:nth-last-of-type(31){bottom:775px;transform:scale(.96);z-index:9968;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(32),:host.growlBottomRight:nth-last-of-type(32){bottom:800px;transform:scale(.96);z-index:9967;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(33),:host.growlBottomRight:nth-last-of-type(33){bottom:825px;transform:scale(.96);z-index:9966;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(34),:host.growlBottomRight:nth-last-of-type(34){bottom:850px;transform:scale(.96);z-index:9965;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(35),:host.growlBottomRight:nth-last-of-type(35){bottom:875px;transform:scale(.96);z-index:9964;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(36),:host.growlBottomRight:nth-last-of-type(36){bottom:900px;transform:scale(.96);z-index:9963;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(37),:host.growlBottomRight:nth-last-of-type(37){bottom:925px;transform:scale(.96);z-index:9962;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(38),:host.growlBottomRight:nth-last-of-type(38){bottom:950px;transform:scale(.96);z-index:9961;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(39),:host.growlBottomRight:nth-last-of-type(39){bottom:975px;transform:scale(.96);z-index:9960;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(40),:host.growlBottomRight:nth-last-of-type(40){bottom:1000px;transform:scale(.96);z-index:9959;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(41),:host.growlBottomRight:nth-last-of-type(41){bottom:1025px;transform:scale(.96);z-index:9958;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(42),:host.growlBottomRight:nth-last-of-type(42){bottom:1050px;transform:scale(.96);z-index:9957;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(43),:host.growlBottomRight:nth-last-of-type(43){bottom:1075px;transform:scale(.96);z-index:9956;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(44),:host.growlBottomRight:nth-last-of-type(44){bottom:1100px;transform:scale(.96);z-index:9955;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(45),:host.growlBottomRight:nth-last-of-type(45){bottom:1125px;transform:scale(.96);z-index:9954;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(46),:host.growlBottomRight:nth-last-of-type(46){bottom:1150px;transform:scale(.96);z-index:9953;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(47),:host.growlBottomRight:nth-last-of-type(47){bottom:1175px;transform:scale(.96);z-index:9952;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(48),:host.growlBottomRight:nth-last-of-type(48){bottom:1200px;transform:scale(.96);z-index:9951;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(49),:host.growlBottomRight:nth-last-of-type(49){bottom:1225px;transform:scale(.96);z-index:9950;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(50),:host.growlBottomRight:nth-last-of-type(50){bottom:1250px;transform:scale(.96);z-index:9949;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(51),:host.growlBottomRight:nth-last-of-type(51){bottom:1275px;transform:scale(.96);z-index:9948;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(52),:host.growlBottomRight:nth-last-of-type(52){bottom:1300px;transform:scale(.96);z-index:9947;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(53),:host.growlBottomRight:nth-last-of-type(53){bottom:1325px;transform:scale(.96);z-index:9946;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(54),:host.growlBottomRight:nth-last-of-type(54){bottom:1350px;transform:scale(.96);z-index:9945;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(55),:host.growlBottomRight:nth-last-of-type(55){bottom:1375px;transform:scale(.96);z-index:9944;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(56),:host.growlBottomRight:nth-last-of-type(56){bottom:1400px;transform:scale(.96);z-index:9943;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(57),:host.growlBottomRight:nth-last-of-type(57){bottom:1425px;transform:scale(.96);z-index:9942;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(58),:host.growlBottomRight:nth-last-of-type(58){bottom:1450px;transform:scale(.96);z-index:9941;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(59),:host.growlBottomRight:nth-last-of-type(59){bottom:1475px;transform:scale(.96);z-index:9940;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(60),:host.growlBottomRight:nth-last-of-type(60){bottom:1500px;transform:scale(.96);z-index:9939;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(61),:host.growlBottomRight:nth-last-of-type(61){bottom:1525px;transform:scale(.96);z-index:9938;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(62),:host.growlBottomRight:nth-last-of-type(62){bottom:1550px;transform:scale(.96);z-index:9937;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(63),:host.growlBottomRight:nth-last-of-type(63){bottom:1575px;transform:scale(.96);z-index:9936;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(64),:host.growlBottomRight:nth-last-of-type(64){bottom:1600px;transform:scale(.96);z-index:9935;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(65),:host.growlBottomRight:nth-last-of-type(65){bottom:1625px;transform:scale(.96);z-index:9934;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(66),:host.growlBottomRight:nth-last-of-type(66){bottom:1650px;transform:scale(.96);z-index:9933;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(67),:host.growlBottomRight:nth-last-of-type(67){bottom:1675px;transform:scale(.96);z-index:9932;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(68),:host.growlBottomRight:nth-last-of-type(68){bottom:1700px;transform:scale(.96);z-index:9931;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(69),:host.growlBottomRight:nth-last-of-type(69){bottom:1725px;transform:scale(.96);z-index:9930;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(70),:host.growlBottomRight:nth-last-of-type(70){bottom:1750px;transform:scale(.96);z-index:9929;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(71),:host.growlBottomRight:nth-last-of-type(71){bottom:1775px;transform:scale(.96);z-index:9928;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(72),:host.growlBottomRight:nth-last-of-type(72){bottom:1800px;transform:scale(.96);z-index:9927;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(73),:host.growlBottomRight:nth-last-of-type(73){bottom:1825px;transform:scale(.96);z-index:9926;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(74),:host.growlBottomRight:nth-last-of-type(74){bottom:1850px;transform:scale(.96);z-index:9925;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(75),:host.growlBottomRight:nth-last-of-type(75){bottom:1875px;transform:scale(.96);z-index:9924;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(76),:host.growlBottomRight:nth-last-of-type(76){bottom:1900px;transform:scale(.96);z-index:9923;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(77),:host.growlBottomRight:nth-last-of-type(77){bottom:1925px;transform:scale(.96);z-index:9922;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(78),:host.growlBottomRight:nth-last-of-type(78){bottom:1950px;transform:scale(.96);z-index:9921;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(79),:host.growlBottomRight:nth-last-of-type(79){bottom:1975px;transform:scale(.96);z-index:9920;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(80),:host.growlBottomRight:nth-last-of-type(80){bottom:2000px;transform:scale(.96);z-index:9919;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(81),:host.growlBottomRight:nth-last-of-type(81){bottom:2025px;transform:scale(.96);z-index:9918;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(82),:host.growlBottomRight:nth-last-of-type(82){bottom:2050px;transform:scale(.96);z-index:9917;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(83),:host.growlBottomRight:nth-last-of-type(83){bottom:2075px;transform:scale(.96);z-index:9916;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(84),:host.growlBottomRight:nth-last-of-type(84){bottom:2100px;transform:scale(.96);z-index:9915;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(85),:host.growlBottomRight:nth-last-of-type(85){bottom:2125px;transform:scale(.96);z-index:9914;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(86),:host.growlBottomRight:nth-last-of-type(86){bottom:2150px;transform:scale(.96);z-index:9913;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(87),:host.growlBottomRight:nth-last-of-type(87){bottom:2175px;transform:scale(.96);z-index:9912;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(88),:host.growlBottomRight:nth-last-of-type(88){bottom:2200px;transform:scale(.96);z-index:9911;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(89),:host.growlBottomRight:nth-last-of-type(89){bottom:2225px;transform:scale(.96);z-index:9910;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(90),:host.growlBottomRight:nth-last-of-type(90){bottom:2250px;transform:scale(.96);z-index:9909;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(91),:host.growlBottomRight:nth-last-of-type(91){bottom:2275px;transform:scale(.96);z-index:9908;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(92),:host.growlBottomRight:nth-last-of-type(92){bottom:2300px;transform:scale(.96);z-index:9907;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(93),:host.growlBottomRight:nth-last-of-type(93){bottom:2325px;transform:scale(.96);z-index:9906;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(94),:host.growlBottomRight:nth-last-of-type(94){bottom:2350px;transform:scale(.96);z-index:9905;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(95),:host.growlBottomRight:nth-last-of-type(95){bottom:2375px;transform:scale(.96);z-index:9904;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(96),:host.growlBottomRight:nth-last-of-type(96){bottom:2400px;transform:scale(.96);z-index:9903;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(97),:host.growlBottomRight:nth-last-of-type(97){bottom:2425px;transform:scale(.96);z-index:9902;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(98),:host.growlBottomRight:nth-last-of-type(98){bottom:2450px;transform:scale(.96);z-index:9901;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(99),:host.growlBottomRight:nth-last-of-type(99){bottom:2475px;transform:scale(.96);z-index:9900;filter:brightness(.8571428571)}:host.growlBottomLeft:nth-last-of-type(100),:host.growlBottomRight:nth-last-of-type(100){bottom:2500px;transform:scale(.96);z-index:9899;filter:brightness(.8571428571)}:host.growlBottomLeft:last-of-type,:host.growlBottomRight:last-of-type,:host.growlTopLeft:last-of-type,:host.growlTopRight:last-of-type{box-shadow:0 1px 3px #00000080}:host.growlBottomRight,:host.growlTopRight{right:-100%;left:auto;width:calc(100% - 30px);transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomRight.animate,:host.growlTopRight.animate{right:1rem}:host:not(.launched){animation:embedded-slide-in .2s ease-in-out}:host.dialogue .toast-content{display:flex;flex-direction:row!important;align-items:center}:host.dialogue p.message-only{flex:3 0 0}:host.dialogue .dialogue{display:inherit}:host.black{color:#fff;background:#000}:host.novo-accent-black{border:1px solid #000000;background:#e6e6e6;color:#3d464d}:host.white{color:#3d464d;background:#fff}:host.novo-accent-white{border:1px solid #ffffff;background:#e6e6e6;color:#3d464d}:host.gray{color:#3d464d;background:#9e9e9e}:host.novo-accent-gray{border:1px solid #9e9e9e;background:#e6e6e6;color:#3d464d}:host.grey{color:#3d464d;background:#9e9e9e}:host.novo-accent-grey{border:1px solid #9e9e9e;background:#e6e6e6;color:#3d464d}:host.offWhite{color:#3d464d;background:#f7f7f7}:host.novo-accent-offWhite{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.bright{color:#3d464d;background:#f7f7f7}:host.novo-accent-bright{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.light{color:#3d464d;background:#dbdbdb}:host.novo-accent-light{border:1px solid #dbdbdb;background:#e6e6e6;color:#3d464d}:host.neutral{color:#fff;background:#4f5361}:host.novo-accent-neutral{border:1px solid #4f5361;background:#e3e4e8;color:#3d464d}:host.dark{color:#fff;background:#3d464d}:host.novo-accent-dark{border:1px solid #3d464d;background:#e3e6e8;color:#3d464d}:host.orange{color:#3d464d;background:#ff6900}:host.novo-accent-orange{border:1px solid #ff6900;background:#ffe1cc;color:#3d464d}:host.navigation{color:#fff;background:#202945}:host.novo-accent-navigation{border:1px solid #202945;background:#dce1ef;color:#3d464d}:host.skyBlue{color:#fff;background:#009bdf}:host.novo-accent-skyBlue{border:1px solid #009bdf;background:#ccefff;color:#3d464d}:host.steel{color:#fff;background:#5b6770}:host.novo-accent-steel{border:1px solid #5b6770;background:#e3e6e8;color:#3d464d}:host.metal{color:#fff;background:#637893}:host.novo-accent-metal{border:1px solid #637893;background:#e1e5ea;color:#3d464d}:host.sand{color:#3d464d;background:#f4f4f4}:host.novo-accent-sand{border:1px solid #f4f4f4;background:#e6e6e6;color:#3d464d}:host.silver{color:#3d464d;background:#e2e2e2}:host.novo-accent-silver{border:1px solid #e2e2e2;background:#e6e6e6;color:#3d464d}:host.stone{color:#3d464d;background:#bebebe}:host.novo-accent-stone{border:1px solid #bebebe;background:#e6e6e6;color:#3d464d}:host.ash{color:#3d464d;background:#a0a0a0}:host.novo-accent-ash{border:1px solid #a0a0a0;background:#e6e6e6;color:#3d464d}:host.slate{color:#fff;background:#707070}:host.novo-accent-slate{border:1px solid #707070;background:#e6e6e6;color:#3d464d}:host.onyx{color:#fff;background:#526980}:host.novo-accent-onyx{border:1px solid #526980;background:#e0e6eb;color:#3d464d}:host.charcoal{color:#fff;background:#282828}:host.novo-accent-charcoal{border:1px solid #282828;background:#e6e6e6;color:#3d464d}:host.moonlight{color:#fff;background:#1a242f}:host.novo-accent-moonlight{border:1px solid #1a242f;background:#dee5ed;color:#3d464d}:host.midnight{color:#fff;background:#202945}:host.novo-accent-midnight{border:1px solid #202945;background:#dce1ef;color:#3d464d}:host.darkness{color:#fff;background:#161f27}:host.novo-accent-darkness{border:1px solid #161f27;background:#dee6ed;color:#3d464d}:host.navy{color:#fff;background:#0d2d42}:host.novo-accent-navy{border:1px solid #0d2d42;background:#d4e9f7;color:#3d464d}:host.aqua{color:#3d464d;background:#3bafda}:host.novo-accent-aqua{border:1px solid #3bafda;background:#d4edf7;color:#3d464d}:host.ocean{color:#fff;background:#4a89dc}:host.novo-accent-ocean{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.mint{color:#3d464d;background:#37bc9b}:host.novo-accent-mint{border:1px solid #37bc9b;background:#d8f3ed;color:#3d464d}:host.grass{color:#fff;background:#8cc152}:host.novo-accent-grass{border:1px solid #8cc152;background:#e6f2d9;color:#3d464d}:host.sunflower{color:#fff;background:#f6b042}:host.novo-accent-sunflower{border:1px solid #f6b042;background:#fdebce;color:#3d464d}:host.bittersweet{color:#fff;background:#eb6845}:host.novo-accent-bittersweet{border:1px solid #eb6845;background:#fadad1;color:#3d464d}:host.grapefruit{color:#fff;background:#da4453}:host.novo-accent-grapefruit{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.carnation{color:#fff;background:#d770ad}:host.novo-accent-carnation{border:1px solid #d770ad;background:#f4d7e8;color:#3d464d}:host.lavender{color:#fff;background:#967adc}:host.novo-accent-lavender{border:1px solid #967adc;background:#dfd7f4;color:#3d464d}:host.mountain{color:#fff;background:#9678b6}:host.novo-accent-mountain{border:1px solid #9678b6;background:#e5deed;color:#3d464d}:host.info{color:#fff;background:#4a89dc}:host.novo-accent-info{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.positive{color:#fff;background:#4a89dc}:host.novo-accent-positive{border:1px solid #4a89dc;background:#d4e3f7;color:#3d464d}:host.success{color:#fff;background:#8cc152}:host.novo-accent-success{border:1px solid #8cc152;background:#e6f2d9;color:#3d464d}:host.negative{color:#fff;background:#da4453}:host.novo-accent-negative{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.danger{color:#fff;background:#da4453}:host.novo-accent-danger{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.error{color:#fff;background:#da4453}:host.novo-accent-error{border:1px solid #da4453;background:#f7d4d8;color:#3d464d}:host.warning{color:#fff;background:#f6b042}:host.novo-accent-warning{border:1px solid #f6b042;background:#fdebce;color:#3d464d}:host.empty{color:#3d464d;background:#cccdcc}:host.novo-accent-empty{border:1px solid #cccdcc;background:#e5e6e5;color:#3d464d}:host.disabled{color:#3d464d;background:#bebebe}:host.novo-accent-disabled{border:1px solid #bebebe;background:#e6e6e6;color:#3d464d}:host.background{color:#3d464d;background:#f7f7f7}:host.novo-accent-background{border:1px solid #f7f7f7;background:#e6e6e6;color:#3d464d}:host.backgroundDark{color:#3d464d;background:#e2e2e2}:host.novo-accent-backgroundDark{border:1px solid #e2e2e2;background:#e6e6e6;color:#3d464d}:host.presentation{color:#fff;background:#5b6770}:host.novo-accent-presentation{border:1px solid #5b6770;background:#e3e6e8;color:#3d464d}:host.bullhorn{color:#3d464d;background:#ff6900}:host.novo-accent-bullhorn{border:1px solid #ff6900;background:#ffe1cc;color:#3d464d}:host.pulse{color:#3d464d;background:#3bafda}:host.novo-accent-pulse{border:1px solid #3bafda;background:#d4edf7;color:#3d464d}:host.company{color:#fff;background:#39d}:host.novo-accent-company{border:1px solid #3399dd;background:#d3e9f8;color:#3d464d}:host.candidate{color:#fff;background:#4b7}:host.novo-accent-candidate{border:1px solid #44bb77;background:#daf1e4;color:#3d464d}:host.lead{color:#fff;background:#a69}:host.novo-accent-lead{border:1px solid #aa6699;background:#eddee9;color:#3d464d}:host.contact{color:#fff;background:#fa4}:host.novo-accent-contact{border:1px solid #ffaa44;background:#ffe8cc;color:#3d464d}:host.clientcontact{color:#fff;background:#fa4}:host.novo-accent-clientcontact{border:1px solid #ffaa44;background:#ffe8cc;color:#3d464d}:host.opportunity{color:#fff;background:#625}:host.novo-accent-opportunity{border:1px solid #662255;background:#f2d9ec;color:#3d464d}:host.job{color:#fff;background:#b56}:host.novo-accent-job{border:1px solid #bb5566;background:#f0dbde;color:#3d464d}:host.joborder{color:#fff;background:#b56}:host.novo-accent-joborder{border:1px solid #bb5566;background:#f0dbde;color:#3d464d}:host.submission{color:#3d464d;background:#a9adbb}:host.novo-accent-submission{border:1px solid #a9adbb;background:#e3e4e8;color:#3d464d}:host.sendout{color:#fff;background:#747884}:host.novo-accent-sendout{border:1px solid #747884;background:#e4e5e7;color:#3d464d}:host.placement{color:#fff;background:#0b344f}:host.novo-accent-placement{border:1px solid #0b344f;background:#d2e9f9;color:#3d464d}:host.note{color:#fff;background:#747884}:host.novo-accent-note{border:1px solid #747884;background:#e4e5e7;color:#3d464d}:host.contract{color:#fff;background:#454ea0}:host.novo-accent-contract{border:1px solid #454ea0;background:#dbddf0;color:#3d464d}:host.jobCode{color:#fff;background:#696d79}:host.novo-accent-jobCode{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.earnCode{color:#fff;background:#696d79}:host.novo-accent-earnCode{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.invoiceStatement{color:#fff;background:#696d79}:host.novo-accent-invoiceStatement{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.billableCharge{color:#fff;background:#696d79}:host.novo-accent-billableCharge{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.payableCharge{color:#fff;background:#696d79}:host.novo-accent-payableCharge{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.user{color:#fff;background:#696d79}:host.novo-accent-user{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.corporateUser{color:#fff;background:#696d79}:host.novo-accent-corporateUser{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.distributionList{color:#fff;background:#696d79}:host.novo-accent-distributionList{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.credential{color:#fff;background:#696d79}:host.novo-accent-credential{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}:host.person{color:#fff;background:#696d79}:host.novo-accent-person{border:1px solid #696d79;background:#e4e5e7;color:#3d464d}@keyframes embedded-slide-in{0%{transform:translateY(-100%);opacity:0}to{transform:translateY(0);opacity:1}}@media screen and (min-width: 350px){:host[class*=growl]{min-width:350px}:host.growlBottomLeft,:host.growlTopLeft{left:-100%;right:auto;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomLeft.animate,:host.growlTopLeft.animate{left:1rem}:host.growlBottomRight,:host.growlTopRight{right:-100%;left:auto;transition:all .5s cubic-bezier(.35,0,.25,1)}:host.growlBottomRight.animate,:host.growlTopRight.animate{right:1rem}}\n"] }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }], propDecorators: { appearance: [{
                type: Input
            }], theme: [{
                type: Input
            }], icon: [{
                type: Input
            }], title: [{
                type: Input
            }], action: [{
                type: Input
            }], hasDialogue: [{
                type: Input
            }], link: [{
                type: Input
            }], isCloseable: [{
                type: Input
            }], message: [{
                type: Input
            }], closed: [{
                type: Output
            }] } });

// NG2
class NovoToastModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.12", ngImport: i0, type: NovoToastModule, declarations: [NovoToastElement], imports: [CommonModule, NovoButtonModule], exports: [NovoToastElement] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastModule, imports: [CommonModule, NovoButtonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, NovoButtonModule],
                    declarations: [NovoToastElement],
                    exports: [NovoToastElement],
                }]
        }] });

// NG2
class NovoToastService {
    constructor(componentUtils) {
        this.componentUtils = componentUtils;
        this.references = [];
        this.icons = { default: 'bell', success: 'check', info: 'info', warning: 'warning', danger: 'remove' };
        this.defaults = { hideDelay: 3500, position: 'growlTopRight', theme: 'default' };
    }
    set parentViewContainer(view) {
        this._parentViewContainer = view;
    }
    alert(options, toastElement = NovoToastElement) {
        return new Promise((resolve) => {
            if (!this._parentViewContainer) {
                console.error('No parent view container specified for the ToastService. Set it inside your main application. \nthis.toastService.parentViewContainer = view (ViewContainerRef)');
                return;
            }
            const toast = this.componentUtils.append(toastElement, this._parentViewContainer);
            this.references.push(toast);
            this.handleAlert(toast.instance, options);
            resolve(toast.instance);
        });
    }
    isVisible(toast) {
        return toast.show;
    }
    hide(toast) {
        toast.animate = false;
        setTimeout(() => {
            toast.show = false;
            const REF = this.references.filter((x) => x.instance === toast)[0];
            if (REF) {
                this.references.splice(this.references.indexOf(REF), 1);
                REF.destroy();
            }
        }, 300);
    }
    handleAlert(toast, options) {
        this.setToastOnSession(toast, options);
        setTimeout(() => {
            this.show(toast);
        }, 20);
        if (!toast.isCloseable) {
            this.toastTimer(toast);
        }
    }
    setToastOnSession(toast, opts) {
        const OPTIONS = typeof opts === 'object' ? opts : {};
        toast.parent = this;
        toast.title = OPTIONS.title || '';
        toast.message = OPTIONS.message || '';
        toast.action = OPTIONS.action || null;
        toast.hideDelay = OPTIONS.hideDelay || this.defaults.hideDelay;
        toast.link = OPTIONS.link || '';
        toast.isCloseable = OPTIONS.isCloseable || false;
        const CUSTOM_CLASS = OPTIONS.customClass || '';
        const ALERT_STYLE = OPTIONS.accent ? `novo-accent-${OPTIONS.accent}` : OPTIONS.theme || this.defaults.theme;
        const ALERT_POSITION = OPTIONS.position || this.defaults.position;
        const ALERT_ICON = OPTIONS.icon || this.icons.default;
        toast.iconClass = `bhi-${ALERT_ICON}`;
        toast.launched = true;
        toast.alertTheme = `${ALERT_STYLE} ${ALERT_POSITION} ${CUSTOM_CLASS} toast-container launched`;
    }
    show(toast) {
        toast.show = true;
        setTimeout(addClass, 25);
        /**
         * Adds animate class to be called after a timeout
         **/
        function addClass() {
            toast.animate = true;
        }
    }
    toastTimer(toast) {
        if (toast.hideDelay < 0) {
            return;
        }
        setTimeout(() => {
            this.hide(toast);
        }, toast.hideDelay);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastService, deps: [{ token: i1$1.ComponentUtils }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: NovoToastService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.ComponentUtils }] });

/**
 * Generated bundle index. Do not edit.
 */

export { NovoToastElement, NovoToastModule, NovoToastService };
//# sourceMappingURL=novo-elements-elements-toast.mjs.map
